Class: Aws::TranscribeStreamingService::Types::MedicalEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribestreamingservice/types.rb

Overview

Contains entities identified as personal health information (PHI) in your transcription output, along with various associated attributes. Examples include category, confidence score, type, stability score, and start and end times.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#category ⇒ String

The category of information identified. The only category is PHI.

Returns:

  • (String)


735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 735

class MedicalEntity < Struct.new(
  :start_time,
  :end_time,
  :category,
  :content,
  :confidence)
  SENSITIVE = []
  include Aws::Structure
end

#confidence ⇒ Float

The confidence score associated with the identified PHI entity in your audio.

Confidence scores are values between 0 and 1. A larger value indicates a higher probability that the identified entity correctly matches the entity spoken in your media.

Returns:

  • (Float)


735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 735

class MedicalEntity < Struct.new(
  :start_time,
  :end_time,
  :category,
  :content,
  :confidence)
  SENSITIVE = []
  include Aws::Structure
end

#content ⇒ String

The word or words identified as PHI.

Returns:

  • (String)


735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 735

class MedicalEntity < Struct.new(
  :start_time,
  :end_time,
  :category,
  :content,
  :confidence)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ Float

The end time, in seconds, of the utterance that was identified as PHI.

Returns:

  • (Float)


735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 735

class MedicalEntity < Struct.new(
  :start_time,
  :end_time,
  :category,
  :content,
  :confidence)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Float

The start time, in seconds, of the utterance that was identified as PHI.

Returns:

  • (Float)


735
736
737
738
739
740
741
742
743
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 735

class MedicalEntity < Struct.new(
  :start_time,
  :end_time,
  :category,
  :content,
  :confidence)
  SENSITIVE = []
  include Aws::Structure
end