Class: Aws::TranscribeStreamingService::Types::MedicalScribeResultStream
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::TranscribeStreamingService::Types::MedicalScribeResultStream
- Defined in:
- lib/aws-sdk-transcribestreamingservice/types.rb
Overview
Result stream where you will receive the output events. The details
are provided in the MedicalScribeTranscriptEvent object.
EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3232 def event_types [ :transcript_event, :bad_request_exception, :limit_exceeded_exception, :internal_failure_exception, :conflict_exception, :service_unavailable_exception ] end |