Class: Aws::TranscribeStreamingService::Types::MedicalTranscriptEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribestreamingservice/types.rb

Overview

The MedicalTranscriptEvent associated with a MedicalTranscriptResultStream.

Contains a set of transcription results from one or more audio segments, along with additional information per your request parameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



1437
1438
1439
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 1437

def event_type
  @event_type
end

#transcriptTypes::MedicalTranscript

Contains Results, which contains a set of transcription results from one or more audio segments, along with additional information per your request parameters. This can include information relating to alternative transcriptions, channel identification, partial result stabilization, language identification, and other transcription-related data.



1437
1438
1439
1440
1441
1442
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 1437

class MedicalTranscriptEvent < Struct.new(
  :transcript,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end