Class: Aws::TranscribeStreamingService::Types::StartStreamTranscriptionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribestreamingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_identification_type ⇒ String

Shows whether content identification was enabled for your transcription.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#content_redaction_type ⇒ String

Shows whether content redaction was enabled for your transcription.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#enable_channel_identification ⇒ Boolean

Shows whether channel identification was enabled for your transcription.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#enable_partial_results_stabilization ⇒ Boolean

Shows whether partial results stabilization was enabled for your transcription.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#identify_language ⇒ Boolean

Shows whether automatic language identification was enabled for your transcription.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#identify_multiple_languages ⇒ Boolean

Shows whether automatic multi-language identification was enabled for your transcription.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#language_code ⇒ String

Provides the language code that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#language_model_name ⇒ String

Provides the name of the custom language model that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#language_options ⇒ String

Provides the language codes that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#media_encoding ⇒ String

Provides the media encoding you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#media_sample_rate_hertz ⇒ Integer

Provides the sample rate that you specified in your request.

Returns:

  • (Integer)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_channels ⇒ Integer

Provides the number of channels that you specified in your request.

Returns:

  • (Integer)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#partial_results_stability ⇒ String

Provides the stabilization level used for your transcription.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#pii_entity_types ⇒ String

Lists the PII entity types you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#preferred_language ⇒ String

Provides the preferred language that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

Provides the identifier for your streaming request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#session_id ⇒ String

Provides the identifier for your transcription session.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#session_resume_window ⇒ Integer

Provides the session resume window, in minutes, that you specified in your request.

Returns:

  • (Integer)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#show_speaker_label ⇒ Boolean

Shows whether speaker partitioning was enabled for your transcription.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_format ⇒ String

Provides the transcript format that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#transcript_result_stream ⇒ Types::TranscriptResultStream

Provides detailed information about your streaming session.



2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_filter_method ⇒ String

Provides the vocabulary filtering method used in your transcription.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_filter_name ⇒ String

Provides the name of the custom vocabulary filter that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_filter_names ⇒ String

Provides the names of the custom vocabulary filters that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_name ⇒ String

Provides the name of the custom vocabulary that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_names ⇒ String

Provides the names of the custom vocabularies that you specified in your request.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 2960

class StartStreamTranscriptionResponse < Struct.new(
  :request_id,
  :language_code,
  :media_sample_rate_hertz,
  :media_encoding,
  :vocabulary_name,
  :session_id,
  :transcript_result_stream,
  :vocabulary_filter_name,
  :vocabulary_filter_method,
  :show_speaker_label,
  :enable_channel_identification,
  :number_of_channels,
  :enable_partial_results_stabilization,
  :partial_results_stability,
  :content_identification_type,
  :content_redaction_type,
  :pii_entity_types,
  :language_model_name,
  :identify_language,
  :language_options,
  :preferred_language,
  :identify_multiple_languages,
  :vocabulary_names,
  :vocabulary_filter_names,
  :session_resume_window,
  :transcript_format)
  SENSITIVE = []
  include Aws::Structure
end