Class: Aws::TranscribeStreamingService::Types::TranscriptEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribestreamingservice/types.rb

Overview

The TranscriptEvent associated with a TranscriptResultStream.

Contains a set of transcription results from one or more audio segments, along with additional information per your request parameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



3029
3030
3031
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3029

def event_type
  @event_type
end

#transcriptTypes::Transcript

Contains Results, which contains a set of transcription results from one or more audio segments, along with additional information per your request parameters. This can include information relating to alternative transcriptions, channel identification, partial result stabilization, language identification, and other transcription-related data.

Returns:



3029
3030
3031
3032
3033
3034
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3029

class TranscriptEvent < Struct.new(
  :transcript,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end