Class: Aws::TranscribeStreamingService::Types::UtteranceEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeStreamingService::Types::UtteranceEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribestreamingservice/types.rb
Overview
Contains set of transcription results from one or more audio segments, along with additional information about the parameters included in your request. For example, channel definitions, partial result stabilization, sentiment, and issue detection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#begin_offset_millis ⇒ Integer
The time, in milliseconds, from the beginning of the audio stream to the start of the
UtteranceEvent. -
#end_offset_millis ⇒ Integer
The time, in milliseconds, from the beginning of the audio stream to the start of the
UtteranceEvent. -
#entities ⇒ Array<Types::CallAnalyticsEntity>
Contains entities identified as personally identifiable information (PII) in your transcription output.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#is_partial ⇒ Boolean
Indicates whether the segment in the
UtteranceEventis complete (FALSE) or partial (TRUE). -
#issues_detected ⇒ Array<Types::IssueDetected>
Provides the issue that was detected in the specified segment.
-
#items ⇒ Array<Types::CallAnalyticsItem>
Contains words, phrases, or punctuation marks that are associated with the specified
UtteranceEvent. -
#language_code ⇒ String
The language code that represents the language spoken in your audio stream.
-
#language_identification ⇒ Array<Types::CallAnalyticsLanguageWithScore>
The language code of the dominant language identified in your stream.
-
#participant_role ⇒ String
Provides the role of the speaker for each audio channel, either
CUSTOMERorAGENT. -
#sentiment ⇒ String
Provides the sentiment that was detected in the specified segment.
-
#transcript ⇒ String
Contains transcribed text.
-
#utterance_id ⇒ String
The unique identifier that is associated with the specified
UtteranceEvent.
Instance Attribute Details
#begin_offset_millis ⇒ Integer
The time, in milliseconds, from the beginning of the audio stream to
the start of the UtteranceEvent.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#end_offset_millis ⇒ Integer
The time, in milliseconds, from the beginning of the audio stream to
the start of the UtteranceEvent.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#entities ⇒ Array<Types::CallAnalyticsEntity>
Contains entities identified as personally identifiable information (PII) in your transcription output.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
3124 3125 3126 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 def event_type @event_type end |
#is_partial ⇒ Boolean
Indicates whether the segment in the UtteranceEvent is complete
(FALSE) or partial (TRUE).
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#issues_detected ⇒ Array<Types::IssueDetected>
Provides the issue that was detected in the specified segment.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::CallAnalyticsItem>
Contains words, phrases, or punctuation marks that are associated
with the specified UtteranceEvent.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code that represents the language spoken in your audio stream.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#language_identification ⇒ Array<Types::CallAnalyticsLanguageWithScore>
The language code of the dominant language identified in your stream.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#participant_role ⇒ String
Provides the role of the speaker for each audio channel, either
CUSTOMER or AGENT.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#sentiment ⇒ String
Provides the sentiment that was detected in the specified segment.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#transcript ⇒ String
Contains transcribed text.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |
#utterance_id ⇒ String
The unique identifier that is associated with the specified
UtteranceEvent.
3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 3124 class UtteranceEvent < Struct.new( :utterance_id, :is_partial, :participant_role, :begin_offset_millis, :end_offset_millis, :transcript, :items, :entities, :sentiment, :issues_detected, :language_code, :language_identification, :event_type) SENSITIVE = [] include Aws::Structure end |