Class: Aws::TranscribeStreamingService::Types::LimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeStreamingService::Types::LimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribestreamingservice/types.rb
Overview
Your client has exceeded one of the Amazon Transcribe limits, typically the concurrent stream service quota. This error can also occur if a stream exceeds the maximum session duration. In rare cases, this error can also occur if you increase your number of concurrent streams too quickly. Reduce your number of concurrent streams and try your request again using an exponential backoff strategy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
- #message ⇒ String
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
666 667 668 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 666 def event_type @event_type end |
#message ⇒ String
666 667 668 669 670 671 |
# File 'lib/aws-sdk-transcribestreamingservice/types.rb', line 666 class LimitExceededException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |